@@ -1,12 +1,12 @@
-use crate::{app::App, ssh_config_store::SshGroupItem};
+use crate::{app::App, ssh_config_store::SshGroupItem, widgets::block, THEME};
 use std::io::Stdout;
 use sublime_fuzzy::best_match;
 use tui::{
     backend::CrosstermBackend,
     layout::Rect,
-    style::{Color, Modifier, Style},
+    style::{Modifier, Style},
     text::{Span, Spans},
-    widgets::{Block, Borders, Paragraph},
+    widgets::Paragraph,
     Frame,
 };
 
@@ -44,15 +44,10 @@ impl Searcher {
     }
 
     pub fn render(&self, _app: &App, area: Rect, frame: &mut Frame<CrosstermBackend<Stdout>>) {
-        let block = Block::default()
-            .borders(Borders::ALL)
-            .border_style(Style::default().fg(Color::LightMagenta))
-            .title_alignment(tui::layout::Alignment::Center)
-            .border_type(tui::widgets::BorderType::Rounded)
-            .title(Span::styled(" Search ", Style::default().fg(Color::White)));
+        let block = block::new(" Search ");
 
         let spans = Spans::from(vec![
-            Span::styled(" > ", Style::default().fg(Color::Magenta)),
+            Span::styled(" > ", Style::default().fg(THEME.text_primary())),
             Span::styled(
                 &self.search_string,
                 Style::default().add_modifier(Modifier::BOLD),
